 <!doctype html>
<html lang="en">
  <head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title> </title>
    <link href="https2://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/css/bootstrap.min.css" rel="stylesheet" integrity="sha384-QWTKZyjpPEjISv5WaRU9OFeRpok6YctnYmDr5pNlyT2bRjXh0JMhjY6hW+ALEwIH" crossorigin="anonymous">  
    <link href="https://fonts.googleapis.com/css2?family=Outfit:wght@100;200;300;400;500;600;700;800;900&amp;display=swap" rel="stylesheet">
    
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/css/bootstrap.min.css" rel="stylesheet">
    <script src="https://code.jquery.com/jquery-3.3.1.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/popper.js/1.11.0/umd/popper.min.js" integrity="sha384-b/U6ypiBEHpOf/4+1nzFpr53nxSS+GLCkfwBdFNTxtclqqenISfwAzpKaMNFNmj4" crossorigin="anonymous"></script>
    <script src="ht2tps://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/js/bootstrap.bundle.min.js"></script>
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.2.1/js/bootstrap.min.js"></script>
  </head>
  <body style="background: #fefefe;">
  <Style>
.navbar2 {width:100%;position:fixed;background-color: #f2f2f2;font-family: 'Outfit';box-shadow:1px 4px 13px -1px #bfbfbf;}
.navbar2 a {float: left;font-size: 15px;color: #777;text-align: center;padding: 4px 12px;text-decoration: none;}
.dropdown2 {float: left;overflow: hidden;}
.dropdown2 .dropbtn {font-size:15px;border: none;outline: none;color: #777;padding: 4px 12px;background-color: inherit;margin: 0;}
.dropdown2 .dropbtn:hover {
    background-color: #ddd;
  color:#444
}

/* Add a red background color to navbar links on hover .dropdown:hover */
.navbar2 a:hover,  .dropbtn {
  background-color: #ddd;
  color:#444;
}

/* Dropdown content (hidden by default) */     
.dropdown-content {
  display: none;
  position: absolute !important;
  background-color: #f9f9f9;
  width: 100%;
  left: 0;
  padding:0px;
  box-shadow: 0px 8px 16px 0px rgba(0,0,0,0.2);
  z-index: 11;
  
}

.dropdown-content a {
  float: none;
  color: #777;
  padding:2px 10px;
  text-decoration: none;
  display: block;
  text-align: left;
  font-weight:normal;
}


 

/* Show the dropdown menu on hover */
.dropdown2:hover .dropdown-content {
  display: block;
  
  
}

 .footerbar2 {
    
    width:100%;
  position:fixed;
  background-color: #ececec;
  font-family: 'Outfit';
  bottom:0; 
   box-shadow:1px 4px 13px -1px #bfbfbf;
}
 
 
 .form-control {
       box-shadow: inset 0 0 10px #f2f1f1;
       font-family: 'Outfit';
       color:#666 !important;
       font-weight:normal;
       margin-bottom:2px !important;
 }
  .form-control-sm {
       box-shadow: inset 0 0 10px #f2f1f1;
       font-family: 'Outfit';
       color:#666 !important;
       font-weight:normal;
       margin-bottom:0px !important;
      
 }
 .modal-content {
     background: #fbfbfb !important;
     border:3px solid #aaa !important;
 }
 .modal-header {
     background: #eee;
     padding: 5px 10px !important;
 }
 .modal-title{
     font-size:16px !important;
 }
 .btn-close{
     font-size:10px;
     
 }
 
 .btn-save {
     border: 1px solid #cacaca;background: #f0efef;color: #555;font-family: 'Outfit';font-size: 12px;padding: 2px;border-radius: 0px;width: 75px;padding-bottom: 2.5px;
      cursor:revert !important;
 }
 .btn-save:hover {
     border: 1px solid #39b6ec;background: #f4feff;color: #555;font-family: 'Outfit';font-size: 12px;padding: 2px;border-radius: 0px;width: 75px;padding-bottom: 2.5px;
      cursor:revert !important;
 }
 .btn-cancel {
     border: 1px solid #cacaca;background: #f0efef;color: #555;font-family: 'Outfit';font-size: 12px;padding: 2px;border-radius: 0px;width: 75px;padding-bottom: 2.5px;
      cursor:revert !important;
 }
  .btn-cancel:hover {
     border: 1px solid #39b6ec;background: #f4feff;color: #555;font-family: 'Outfit';font-size: 12px;padding: 2px;border-radius: 0px;width: 75px;padding-bottom: 2.5px;
      cursor:revert !important;
 }
 .modal-footer {
     padding:5px 15px !important;
 }
 .modal-body{
     padding-top:5px;
 }
 .error_msg{
     color: #f47676;font-size: 12px;
 }
 label {font-size: 14px !important;margin-bottom: 2px !important;color: #333 !important;
 
  -webkit-touch-callout: none; /* iOS Safari */
    -webkit-user-select: none; /* Safari */
     -khtml-user-select: none; /* Konqueror HTML */
       -moz-user-select: none; /* Old versions of Firefox */
        -ms-user-select: none; /* Internet Explorer/Edge */
            user-select: none; /* Non-prefixed version, currently
                                  supported by Chrome, Edge, Opera and Firefox */
 }
 
 .noselect {
  -webkit-touch-callout: none; /* iOS Safari */
    -webkit-user-select: none; /* Safari */
     -khtml-user-select: none; /* Konqueror HTML */
       -moz-user-select: none; /* Old versions of Firefox */
        -ms-user-select: none; /* Internet Explorer/Edge */
            user-select: none; /* Non-prefixed version, currently
                                  supported by Chrome, Edge, Opera and Firefox */
}
.modal-dialog-centered {
  -webkit-touch-callout: none; /* iOS Safari */
    -webkit-user-select: none; /* Safari */
     -khtml-user-select: none; /* Konqueror HTML */
       -moz-user-select: none; /* Old versions of Firefox */
        -ms-user-select: none; /* Internet Explorer/Edge */
            user-select: none; /* Non-prefixed version, currently
                                  supported by Chrome, Edge, Opera and Firefox */
}
/*@import url('https://cdn-uicons.flaticon.com/2.5.1/uicons-regular-straight/css/uicons-regular-straight.css')*/

.highlight_error {
    border:1px solid #dc3545 !important;
    box-Shadow:0 0 5px #dc3545;
}
.highlight_error:hover {
    border:1px solid #dc3545 !important;
    box-Shadow:0 0 5px #dc3545 !important;
}
.highlight_error:focus  {
    border:1px solid #dc3545 !important;
    box-Shadow:0 0 5px #dc3545 !important;
}
.inlineErrmsg {
    color: #e83b3b;
  text-align: center !important;
  background: #ffece8;
  border-radius: 5px;
  width: -moz-available;
  padding: 3px;
 
}
.badge {
    font-size:10px !important
}
.viewLink {
    cursor:pointer;color: #888 !important;font-size:14px !important;
}
.viewLink:hover {
    cursor:pointer;color: #222 !important;font-size:14px !important;
}
.editLink {
    cursor:pointer;color: #888 !important;font-size:14px !important;
}
.editLink:hover {
    cursor:pointer;color: #222 !important;font-size:14px !important;
}
.deleteLink {
    cursor:pointer;color: #ec8787 !important;font-size:15px !important;
}
.deleteLink:hover {
    cursor:pointer;color: #ff0000 !important;font-size:15px !important;
}

.rEven {
    background:#fbfeff !important;
}
.rEven:hover {
    background:#f0fbff  !important;
}

.rEven td {
    background:none;
   
    font-size:16px;
     
} 
.rOdd td {
    background:none;
   
    font-size:16px;
   
} 

.rOdd:hover {
    background:#f0fbff  !important;
} 

</style>
<script>

 var _timer_listLoading;
    function startListLoading() {
       _timer_listLoading = setInterval(function () {
           if ($('#listLoadingSpan').html()==". . .") {
            $('#listLoadingSpan').html(".") ;
           } else if ($('#listLoadingSpan').html()==". .") {
               $('#listLoadingSpan').html(". . .") ;
           } else if ($('#listLoadingSpan').html()==".") {
            $('#listLoadingSpan').html(". .") ;
           } else if ($('#listLoadingSpan').html()=="") {
               $('#listLoadingSpan').html(".") ;
           } else {
               $('#listLoadingSpan').html("") ;
           }
    
}, 1000); 
        
    }
    
    
function sortTable() {
  var table, rows, switching, i, x, y, shouldSwitch;
  table = document.getElementById("myTable");
  switching = true;
  /*Make a loop that will continue until
  no switching has been done:*/
  while (switching) {
    //start by saying: no switching is done:
    switching = false;
    rows = table.rows;
    /*Loop through all table rows (except the
    first, which contains table headers):*/
    for (i = 1; i < (rows.length - 1); i++) {
      //start by saying there should be no switching:
      shouldSwitch = false;
      /*Get the two elements you want to compare,
      one from current row and one from the next:*/
      x = rows[i].getElementsByTagName("TD")[1];
      y = rows[i + 1].getElementsByTagName("TD")[1];
      //check if the two rows should switch place:
      if (x.innerHTML.toLowerCase() > y.innerHTML.toLowerCase()) {
        //if so, mark as a switch and break the loop:
        shouldSwitch = true;
        break;
      }
    }
    if (shouldSwitch) {
      /*If a switch has been marked, make the switch
      and mark that a switch has been done:*/
      rows[i].parentNode.insertBefore(rows[i + 1], rows[i]);
      switching = true;
    }
  }
}
    
function print_inlineError(errMessage) {
   return "<div class='inlineErrmsg'>"+errMessage+"</div>"; 
}
function openPage(page) {
    
    $.post("views.php?action="+page+"&rnd=2", function(data, status){
         clearInterval(_timer_listLoading);
        $('#myPage').html(data);
  });
}
var URL="https://ims.j2jsoftwaresolutions.in/";   
  
 function clearInput(txtBox) {
     $('#Err'+txtBox).html("");
     $("#"+txtBox).removeClass("highlight_error");
}



</script>
<?php
   
?>
<link rel='stylesheet' href='https://cdn-uicons.flaticon.com/2.5.1/uicons-regular-straight/css/uicons-regular-straight.css'>
<div class="navbar2">
    <a href="dashboard.php">Home</a>
    <div class="dropdown2">
        <button class="dropbtn">Masters
            <i class="fa fa-caret-down"></i>
        </button>
        <div class="dropdown-content" style="padding-bottom:10px">
            <div class="row" style="margin:0px">
                <div class="col-sm-2">
                    <div class="menu-heading" style="padding-bottom:10px;padding-top:10px">Miscellaneous</div>
                    <a href="javascript:void(0)" onclick="openPage('mmal')">Athletics</a>
                    <a href="javascript:void(0)" onclick="openPage('mmhl')">Hobbies</a>
                    <a href="javascript:void(0)" onclick="openPage('mmsl')">Sports</a>
                </div>
                <div class="col-sm-2">
                    <div class="menu-heading" style="padding-bottom:10px">Academy</div>
                    <a href="javascript:void(0)" onclick="openPage('mabl')">Batches</a>
                    <a href="javascript:void(0)" onclick="openPage('maayl')">Academic Years</a>
                    <a href="javascript:void(0)" onclick="openPage('macll')">Classes</a>
                    <a href="javascript:void(0)" onclick="openPage('macoul')">Course Names</a>
                    <a href="javascript:void(0)" onclick="openPage('mactl')">Course Types</a>
                    <a href="javascript:void(0)" onclick="openPage('madl')">Departments</a>
                    <a href="javascript:void(0)" onclick="openPage('madvl')">Divisions</a>
                    <a href="javascript:void(0)" onclick="openPage('mael')">Examinations</a>
                    <a href="javascript:void(0)" onclick="openPage('magl')">Grades</a>
                    <a href="javascript:void(0)" onclick="openPage('masl')">Semesters</a>
                    <a href="javascript:void(0)" onclick="openPage('masul')">Subjects</a>
                </div>
                <div class="col-sm-4">
                    <div class="menu-heading" style="padding-bottom:10px">Common</div>
                    <div class="row">
                        <div class="col-sm-6">
                            <a href="javascript:void(0)" onclick="openPage('mcbgl')">Blood Groups</a>
                            <a href="javascript:void(0)" onclick="openPage('mcgl')">Gender</a>
                            <a href="javascript:void(0)" onclick="openPage('mcrnl')">Religion Names</a>
                            <a href="javascript:void(0)" onclick="openPage('mccnl')">Caste Names</a>
                            <a href="javascript:void(0)" onclick="openPage('mccl')">Community Names</a>
                            <a href="javascript:void(0)" onclick="openPage('mcdtl')">Document Types</a>
                            <a href="javascript:void(0)" onclick="openPage('mcitl')">Institution Types</a>
                            <a href="javascript:void(0)" onclick="openPage('mcmsl')">Marital Status</a>
                            <a href="javascript:void(0)" onclick="openPage('mcirl')">Income Ranges</a>
                        </div>
                        
                        <div class="col-sm-6">
                            <a href="javascript:void(0)" onclick="openPage('mccol')">Country Names</a>
                            <a href="javascript:void(0)" onclick="openPage('mcsnl')">State Names</a>
                            <a href="javascript:void(0)" onclick="openPage('mcdnl')">District Names</a>
                            <a href="javascript:void(0)" onclick="openPage('mcanl')">Area Names</a>
                            <a href="javascript:void(0)" onclick="openPage('mcnl')">Nationalities</a>
                            <a href="javascript:void(0)" onclick="openPage('mcll')">Languages</a>
                            <a href="javascript:void(0)" onclick="openPage('mcaql')">Admission Quotas</a>
                            <a href="javascript:void(0)" onclick="openPage('mcatl')">Applicant's Types</a>
                            <a href="javascript:void(0)" onclick="openPage('mcotl')">Occupations</a>
                            <a href="javascript:void(0)" onclick="openPage('mccorl')">Currency Names</a>
                        </div>
                    </div>
                </div>
                <div class="col-sm-2">
                    <div class="menu-heading" style="padding-bottom:10px">App Common</div>
                    <a href="javascript:void(0)" onclick="openPage('macql')">Qualifications</a>
                    <a href="javascript:void(0)" onclick="openPage('masnl')">School Names</a>
                    <a href="javascript:void(0)" onclick="openPage('macoll')">College Names</a>
                    <a href="javascript:void(0)" onclick="openPage('mainl')">Institution Names</a>
                    <a href="javascript:void(0)" onclick="openPage('macbel')">Board of Educations</a>
                    <a href="javascript:void(0)" onclick="openPage('macstl')">Staff Types</a>
                    <a href="javascript:void(0)" onclick="openPage('macscl')">Student Categories</a>
                    <a href="javascript:void(0)" onclick="openPage('macssl')">Student Status</a>
                    <a href="javascript:void(0)" onclick="openPage('macsl')">Scheme Names</a>
                    <a href="javascript:void(0)" onclick="openPage('macunl')">University Names</a>
                    <a href="javascript:void(0)" onclick="openPage('machgnl')">HSc Group Names</a>
                    <a href="javascript:void(0)" onclick="openPage('macdel')">Designations</a>
                </div>
            </div>
        </div>  
    </div>
    
    <div class="dropdown2">
        <button class="dropbtn">Students
            <i class="fa fa-caret-down"></i>
        </button>
        <div class="dropdown-content" style="padding-bottom:10px">
            <div class="row" style="margin:0px">
                <div class="col-sm-2">
                    <div class="menu-heading" style="padding-bottom:10px;padding-top:10px">Student Management</div>
                    <a href="javascript:void(0)" onclick="openPage('smsl')">List</a>
                    <a href="javascript:void(0)" onclick="openPage('smspi')">General Info</a>
                    <a href="javascript:void(0)" onclick="openPage('smsci')">Contact Info</a>
                    <a href="javascript:void(0)" onclick="openPage('smspe')">Previous Education</a>
                    <a href="javascript:void(0)" onclick="openPage('smsd')">Documants</a>
                    <a href="javascript:void(0)" onclick="openPage('smssd1')">Other Details 1</a>
                    <a href="javascript:void(0)" onclick="openPage('smsod2')">Other Details 2</a>
                    <a href="javascript:void(0)" onclick="openPage('smsld')">Library Details</a>
                    <a href="javascript:void(0)" onclick="openPage('smstd')">Transport Details</a>
                    <a href="javascript:void(0)" onclick="openPage('smshd')">Hostel Details</a>
                    <a href="javascript:void(0)" onclick="openPage('smsfd')">Fees Details</a>
                    <a href="javascript:void(0)" onclick="openPage('smsa')">Activities</a>
                    <a href="javascript:void(0)" onclick="openPage('smsss')">Sent SMS</a>
                    <a href="javascript:void(0)" onclick="openPage('smssw')">Sent WhatsApp</a>
                    <a href="javascript:void(0)" onclick="openPage('smsse')">Sent Email</a>
                    <a href="javascript:void(0)" onclick="openPage('smssm')">Sent Messages</a>
                    <a href="javascript:void(0)" onclick="openPage('smsa')">Acess / Permission</a>
                </div>
            </div>
        </div>  
    </div>
    
    <div class="dropdown2">
        <button class="dropbtn">Administrator
            <i class="fa fa-caret-down"></i>
        </button>
        <div class="dropdown-content" style="padding-bottom:10px">
            <div class="row" style="margin:0px">
                <div class="col-sm-2">
                    <div class="menu-heading" style="padding-bottom:10px;padding-top:10px">Admin Management</div>
                    <a href="javascript:void(0)" onclick="openPage('ampl')">Principal</a>
                    <a href="javascript:void(0)" onclick="openPage('amvpl')">Vice Principal</a>
                </div>
            </div>
        </div>  
    </div>
    
    <div class="dropdown2">
        <button class="dropbtn">Staffs
            <i class="fa fa-caret-down"></i>
        </button>
        <div class="dropdown-content" style="padding-bottom:10px">
            <div class="row" style="margin:0px">
                <div class="col-sm-2">
                    <div class="menu-heading" style="padding-bottom:10px;padding-top:10px">Staff Management</div>
                    <a href="javascript:void(0)" onclick="openPage('stfmsn')">New Staff</a>
                    <a href="javascript:void(0)" onclick="openPage('stfmsl')">List Staffs</a>
                </div>
            </div>
        </div>  
    </div>
     
</div> 
   <div style="height:100px"></div>
     <div id="myPage" style="max-width:1280px;min-width:1280px;width:1280px;max-height:85%;min-height:85%;height:85%;overflow:auto;margin:0px auto">
     <h1>Hello, world!</h1>
     <i class="fi fi-rs-trash"></i> <br>
     <i class="fi fi-rs-refresh"></i><br>
     <i class="fi fi-rs-pencil"></i> <br>
     <i class="fi fi-rs-menu-dots"></i> <br>
     <i class="fi fi-rs-web-test"></i><br>
     <i class="fi fi-rr-search"></i>
     
     
         <div class="dropdown" style="display:none">
  <span data-toggle="dropdown" style="cursor:pointer;">
   <i class="fi fi-rs-menu-dots"></i>
  </span>
  <div class="dropdown-menu">
    <a class="dropdown-item" href="#"><i class="fi fi-rs-web-test"></i> View</a>
    <a class="dropdown-item" href="#"><i class="fi fi-rs-pencil"></i> Edit</a>
    <a class="dropdown-item" href="#"><i class="fi fi-rs-trash"></i> Delete</a>
  </div>
</div>  

 <div class="input-group" style="display:none">
            <input class="form-control border-end-0 border rounded-pill" type="text" value="search" id="example-search-input">
            <span class="input-group-append">
                <button class="btn btn-outline-secondary bg-white border-start-0 border rounded-pill ms-n3" type="button">
                    <i class="fi fi-rs-search"></i>
                </button>
            </span>
     </div>
 

     </div>  
    
    <div class="footerbar2">&nbsp;</div>
<script>                 
function openDeleteConfirmation(id,action,method,text,callback) {
    $('#delID').val(id);
    $('#delAction').val(action);
    $('#delMethod').val(method);
    $('#delCallback').val(callback);
    $('#removeText').html(text);
    $('#delete_confirmation').modal("show");               
}
</script>
<div class="modal fade" id="delete_confirmation" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content" style="border:3px solid #fb7a7a !important;background:#fff !important">
            <div class="modal-header" style="background: #fff5f5 !important;border-bottom: 1px solid #f1f1f1;color: #f06e6e;">
                <h5 class="modal-title" id="exampleModalLabel">Confirmation to delete</h5>
                 <button type="button" class="btn-close" data-dismiss="modal"></button>
            </div>
            <div class="modal-body">
             <form id="frm_delete" name="frm_delete" method="post" enctype="multipart/form-data" autocomplete="off">
             <input type="hidden" name="delID" id="delID">
             <input type="hidden" name="delAction" id="delAction">
             <input type="hidden" name="delMethod" id="delMethod">
             <input type="hidden" name="delCallback" id="delCallback">
                <div class="row">
                    <span id="ErreditCommon"></span>
                    <div class="col-2" style="padding-top: 15px;">
                       <img src="assets/information.png" style="width: 48px;opacity: 0.6;">
                    </div>
                     <div class="col-10" style="padding-top: 23px;">
                        are you want to remove <span id="removeText" style="color:red;font-weight:bold"></span>?
                    </div>
                </div>
             </form>
            </div>
            <div class="modal-footer">
                <button type="button" data-dismiss="modal" class="btn-cancel" style="background: #fffbfb;border: 1px solid #fb7a7a;color: #fb7a7a;">Cancel</button>
                <button type="button" href="javascript:void(0)" onclick="callDelete()" class="btn-save" style="border: red;border: 1px solid #fb7a7a;background: #fb7a7a;color: #fff;">Yes, Delete</button>
            </div>
        </div>                                                                                                                     
    </div>
</div>
<Script>
function callDelete() {
    var param = $('#frm_delete').serialize();
    $.post(URL+"webservice.php?action="+$('#delAction').val()+"&method="+$('#delMethod').val(),param,function(data){
        var obj = JSON.parse(data); 
        if (obj.status=="success") {
             $('#delete_confirmation').modal("hide");  
             $('#delete_success_modal').modal("show");
             $('#delete_success_modal_title').html(obj.message);
             list();    
        }   else {
           $('#delete_failure_modal_title').html(obj.message);
        }
    });
}
</script>
<div class="modal fade" id="delete_success_modal" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content" style="width: 300px;margin: 0px auto;background: #fff !important;">
            <div class="modal-body" style="text-align: center;">
                <div id="sucess">
                    <img style="width:96px;" src="assets/deleted_successfully.png" alt=""/>
                </div>
                <h3 id="delete_success_modal_title" style="font-size: 18px;"></h3>  
                 <button type="button" href="javascript:void(0)" onclick="$('#delete_success_modal').modal('hide')" class="btn-save">Continue</button>         
            </div>
        </div>
    </div>
</div>
<div class="modal fade" id="delete_failure_modal" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-body" style="text-align: center;">
                <div id="sucess">
                    <img style="width: 150px;" src="sucess.gif" alt=""/>
                </div>
                <h3 id="delete_failure_modal_title"></h3>  
                 <button type="button" href="javascript:void(0)" onclick="$('#delete_success_modal').modal('hide')" class="btn-save">Continue</button>         
            </div>
        </div>
    </div>
</div>
 
    
